'use strict';

var tslib_es6 = require('../../external/tslib/tslib.es6.js');
var common = require('@nestjs/common');
var constant = require('../../shared/constant/config/constant.js');
var configParameters_provider = require('../../shared/provider/config/config-parameters.provider.js');
var properties_provider = require('../../shared/provider/config/properties.provider.js');
var ssmClient_provider = require('../../shared/provider/config/ssm-client.provider.js');
var parameterStore_service = require('../aws/parameter-store/parameter-store.service.js');
var config_service = require('./config.service.js');

var ParameterStoreConfigModule_1;
exports.ParameterStoreConfigModule = ParameterStoreConfigModule_1 = class ParameterStoreConfigModule {
    static register(options) {
        const propertiesProvider = properties_provider.ParameterStoreConfigPropertiesProvider(options);
        return {
            exports: [config_service.ParameterStoreConfigService, constant.PARAMETER_STORE_CONFIG_PARAMETERS],
            module: ParameterStoreConfigModule_1,
            providers: [propertiesProvider, configParameters_provider.ParameterStoreConfigParametersProvider, ssmClient_provider.ParameterStoreConfigSSMProvider, config_service.ParameterStoreConfigService, parameterStore_service.ParameterStoreService],
        };
    }
    static registerAsync(properties) {
        const providers = this.createAsyncProviders(properties);
        return {
            exports: [config_service.ParameterStoreConfigService, constant.PARAMETER_STORE_CONFIG_PARAMETERS],
            imports: properties.imports ?? [],
            module: ParameterStoreConfigModule_1,
            providers,
        };
    }
    static createAsyncOptionsProvider(properties) {
        if (properties.useFactory) {
            return {
                inject: properties.inject ?? [],
                provide: constant.PARAMETER_STORE_CONFIG_PROPERTIES,
                useFactory: properties.useFactory,
            };
        }
        const inject = properties.useExisting ?? properties.useClass;
        return {
            inject: inject ? [inject] : [],
            provide: constant.PARAMETER_STORE_CONFIG_PROPERTIES,
            useFactory: async (optionsFactory) => {
                return optionsFactory.createOptions();
            },
        };
    }
    static createAsyncProviders(properties) {
        const optionsProvider = this.createAsyncOptionsProvider(properties);
        const requestProviders = [optionsProvider, configParameters_provider.ParameterStoreConfigParametersProvider, ssmClient_provider.ParameterStoreConfigSSMProvider, config_service.ParameterStoreConfigService, parameterStore_service.ParameterStoreService];
        if (properties.useExisting || properties.useFactory || !properties.useClass) {
            return requestProviders;
        }
        return [
            ...requestProviders,
            {
                provide: properties.useClass,
                useClass: properties.useClass,
            },
        ];
    }
};
exports.ParameterStoreConfigModule = ParameterStoreConfigModule_1 = tslib_es6.__decorate([
    common.Global(),
    common.Module({})
], exports.ParameterStoreConfigModule);
//# sourceMappingURL=config.module.js.map
